% e2fit.m
% Second Order Exponential Fit: Iron Loss or Reactive Energy
% Copyright 1995, 1997 James L. Kirtley Jr.
% See 6.11s copyright statement for rules of use
global B P		% required for the evaluator
B0 = 1;			% normalizing flux density
% This little bit of arcanery lets us read data of arbitrary length
% from a file. The filename is of the form 'name.prn' and the user
% is prompted for the 'name' part of it
% Input data is a file with two columns: flux density in the first
% column, loss density in the second. Number of points is not important.
fprintf('Second Order Exponential Curve Fit\n');
foo = input('Fit What? (name.prn) name ==> ','s');
fname = [foo '.prn'];	% this assembles the file name
eval(['load ' fname]);	% and this statement actually loads the data
eval(['data = ' foo ';']);  % this assigns the data to the variable 'data'
B = data(:,1)';		% Flux Density
P = data(:,2)';		% Loss Density
fv = [1 1.7 .01 16]';	% Initial value to use for fmins function
options(1)=1;
options(2)=1e-5;
options(3)=1e-5;
%FOUT = fminunc('fit2err',fv); % use this for Octave 5.2
FOUT = fminsearch('fit2err',fv);	% MATLAB magic!
P0 = FOUT(1);		% These are the finished parameters
EXP = FOUT(2);
P1 = FOUT(3);
EXP1 = FOUT(4);		% and now we check our work
Pfit = P0 .* (B ./ B0) .^ EXP + P1 .* (B ./ B0) .^ EXP1;
semilogy(B, Pfit, B, P, 'o');	%This gives a visual picture
title('Second Order Exponential Curve Fit');
xlabel('Flux Density, T');
ylabel('Watts or Vars Per Unit Mass');

e = sum((Pfit ./ P - 1) .^2)/sum(P .^2);	% Evaluate error
fprintf('Fit Results: P0 = %g   EXP = %g\n',P0, EXP);
fprintf('             P1 = %g   EXP1 = %g\n',P1, EXP1);
fprintf('Relative Error = %g\n',e);
