% efita.m
% First Order Exponential Fit: Iron Loss or Reactive Energy
% Copyright 1995, 1997 James L. Kirtley Jr.
% See 6.11s copyright statement for rules of use
% If this one doesn't work well on your data, try e2fit.m
% and/or pfit.m
global B P		% required for the evaluator
B0 = 1;			% normalizing flux density
% This little bit of arcanery lets us read data of arbitrary length
% from a file. The filename is of the form 'name.prn' and the user
% is prompted for the 'name' part of it
% Input data is a file with two columns: flux density in the first
% column, loss density in the second. Number of points is not important.
fprintf('First Order Exponential Curve Fit\n');
foo = input('Fit What? (name.prn) name ==> ','s');
fname = [foo '.prn'];		% this assembles the file Name
eval(['load ' fname]);		% and this statement actually loads the data
eval(['data = ' foo ';']);	% this assigns the data to the variable 'data'
B = data(:,1)';			% Flux Density				 
P = data(:,2)';			% Loss Density				 
fv = [1 2]';			% Initial value to use for fmins function
options(1)=1;			% nonzero, causes intermediate printing
options(2)=1e-5;		% termination criterion for parameters
options(3)=1e-5;		% termination criterion for function
% [X,FVAL,EXITFLAG,OUTPUT] = FMINSEARCH(FUN,X0,OPTIONS,P1,P2,...)
FOUT = fminunc('fiterr',fv); % use this for Octave 5.2
%FOUT = fminsearch('fiterr',fv); % use this for Matlab or Octave 4
P0 = FOUT(1);			% These are the finished parameters
EXP = FOUT(2);
Pfit = P0 .* (B ./ B0) .^ EXP;
figure(1)
semilogy(B, Pfit, B, P, 'o');
title('First Order Exponential Curve Fit');
xlabel('Flux Density, T');
ylabel('Watts or Vars Per Unit Mass');
e = sum((Pfit ./ P - 1) .^2)/sum(P .^2);
fprintf('Fit Results: P0 = %g   EXP = %g\n',P0, EXP);
fprintf('Relative Error = %g\n',e);
