function [Ro, Rout, Len] = tdensd(p, T, x, td, B0, J0, Nd, lamsi)
% Estimate of torque density of disk machines
% Warning: this is a pretty abstract model!
% Copyright 1995, 1997 James L. Kirtley Jr.
% See 6.11s copyright statement for rules of use
% Set up to do a vector calculation on x and lamsi
% The input variables are:
% p is number of pole pairs
% T is required torque
% x is active inner to outer radius ratio
% td is disk thickness
% B0 is useful magnetic flux density
% J0 is useful current density
% lamsi is slot fraction at the inner radius
% Ro depends on Torque per disk
squig = lamsi .* x .* (1-x) .* ((1+x) ./ 2 - lamsi .* x);
Ro = ((T/Nd) ./ (2*pi*J0*B0*td .* squig)) .^ (1/3);
% Volume Calculation
% Outer Radius 
Rout = Ro .* (1 + (1/p) .* x .* lamsi);
% Length
Len = 2*Nd*td + 2 .* (Ro ./ p) .* (1 - lamsi .* x);

