function [R, Rout, Len] = tdensr(p, T, x, hs, B0, J0, lams)
% Estimate of torque density of cylindrical machines
% Warning: this is a pretty abstract model!
% Calculates volume of machine required to produce a given torque
% Copyright 1995, 1997 James L. Kirtley Jr.
% See 6.11s copyright statement for rules of use
% Set up to do a vector calculation on lams and x
% The input variables are:
% p is number of pole pairs
% T is required torque
% x is length to diameter ratio
% hs is slot depth
% B0 is useful magnetic flux density
% J0 is useful current density
% lams is slot fraction at the active radius
% R is active radius
R = (T ./ (pi*J0*B0*hs .* x .* lams .* (1 - lams))) .^ (1/3);
% Volume Calculation
% Outer Radius 
Rout = R + hs + (R ./ p) .* (1 - lams);
% Length
Len = 2 .* R .* x + (2/p) .* R .* lams; 
