% Vee curve generator
% Copyright 1995, 1997 James L. Kirtley Jr.
% see 611s copyright statement for rules of use
% NOTE: This script does not do armature limits right!

global p0 v xd xq e     % used by one of the subroutines
v=1;			% assumed terminal voltage
np=51;			% number of points per curve

% input a few important variables
xd = input('Direct Axis Reactance xd ==> ');
xq = input('Quadrature Axis Reactance xq ==> ');
eafmax = input('Max Voltage Behind Synchronous Reactance eaf ==> ');
nc = input('How Many Curves to Plot? ==> ');
p = 1/nc:1/nc:1;	% vector of power levels
n = length(p);		% number of power levels

% get zero real power curve first: this case is easy
ez = [0 1 eafmax];
iz = [1/xd 0 (eafmax-v)/xd];
ia = zeros(np,1);	% vector of currents to plot
hold off		% required by one of the oddities of the Student Ed.
clf			% get a fresh plot
axis([0 eafmax 0 1.2]);	% this controls the plot scale
plot(ez, iz);		% plot the zero real power curve
grid			% this generates gridlines
hold on			% so that subsequent plots look good
d = pi/4;		% just a starting point
for i=1:nc,
  % first must find stability point
  % d is the stability limit of delta for given power level
  % fzero finds the zero of the nonlinear function fz
  p0 = p(i);		% remember p0 is a global
  d = fzero('fz',d);	% fzero 'solves' a nonlinear function
  % eafmin is the corresponding field current
  eafmin = (p0 - ((v^2)/2)*(1/xq-1/xd)*sin(2*d))*xd/(v*sin(d));
  eaf = eafmin:(eafmax-eafmin)/(np-1):eafmax;	% each curve is over a 
  m = length(eaf);				% range of values of eaf
  for k=1:m,
    ea = eaf(k);
    e = ea;					% ea is a global
    if (xd == xq),				% round rotor is easier
      delt = asin(p0*xd/(v*ea));
    else
      if k==1,					% already solved...
        delt = d;
      else
        pwr=p0;				% these assignments are to avoid
        va = v;				% using the globals in a function
        xda = xd;			% argument list: a 'bug' in MATLAB
        xqa = xq;
        delt = finddelt(pwr, ea, va, xda, xqa, 0); % get operating point
      end
    end
    % compute reactive power at the operating point
    qr = (v*ea/xd)*cos(delt)+(v^2/2)*(1/xq-1/xd)*cos(2*delt)...
          - (v^2/2)*(1/xd+1/xq);
    ia(k) = sqrt(p0^2+qr^2)/v;		% and here is the current
    fprintf('.');			% let us know prog is working
  end,
fprintf('\n');
plot(eaf, ia);
end
title('Synchronous Machine Vee Curve')
xlabel('Internal Voltage eaf')
ylabel('Per-Unit Armature Current')
