% Design of a DC Commutator, PM motor
% Remember this is a REALLY crude estimator!
% Copyright 1995, 1997 James L. Kirtley Jr.
% See 6.11s copyright statement for rules of use
% Requires the following input variables, contained in var.m:
% Rotor Radius		r
% Active Length		l
% Air-Gap		g
% Magnet Height		hm
% Magnet Angle		thm
% Armature Slots	nr
% Turns per coil	nc
% Wire conductivity	sig
% wire diameter		dw
% voltage		V
% magnet remanent flux	Br

% Two bugger factors:
fl = 1.1;		% leakage factor
ff = 1.2;		% reluctance factor

% First, calculate effective field
Ag = l*(r+.5*g);	% average gap area
Am = l*(r+g+.5*hm);	% average magnet area
Pu = (fl/ff)*(hm/g)*(Ag/Am);	%"unit permeance"
Bd = Br/(1+1/Pu);	% radial flux density

% calculation of effective length
A = .9;			% a bunch of empirical coefficients
B = 7.4 - 9*hm/r;
N = (A/B)*log(1+B*(hm/r));
lstar = l+2*N*r;
leff = lstar/fl;	% effective length

% calculation of effective interaction angle
if(rem(nr,2) == 0),	% even number of slots
  thc = pi*(1-2/nr);
else			% odd number of slots
  thc = pi*(1-1/nr);
end
			
if (thm < thc),		% compare with magnet angle
  th = thm;
else
  th = thc;
end

% calculation of series turns
ns = .5*nr*nc;		% two parallel paths assumed

% Calculation of motor coefficient:
K = r*leff*ns*Bd*th/pi;

% Zero torque speed
omz = V/K;
rpmz = (30/pi)*omz;

% Estimate of rotor resistance
% first, guess length of wire
lw = 2*ns*(l+th*r);
awire = 2*(pi/4)*dw^2;
Ra = lw/(awire*sig);

% print summary output information
fprintf('Commutator Motor:\n');
fprintf('Motor Constant = %g V-s\n',K);
fprintf('Armature Resistance = %g Ohms\n',Ra);
fprintf('Zero Torque Speed at %g Volts = %g RPM\n',V,rpmz);
fprintf('\n');

% Electrical Performance: neglects friction and windage
 
om = 0:omz/20:omz;		% a bunch of points in speed
I = (V - K .* om) ./ Ra;	% armature current
Pe = V .* I;			% electrical input power
Pm = Pe - I .^2 .* Ra;		% mechanical output power
T = K .* I;			% torque
rpm = (30/pi) .* om;		% speed in useful units
subplot(211)			% splits plot screen in two
plot(rpm, T);			% plot torque vs. speed
ylabel('N-m');
title('Torque');
subplot(212)			% second plot
plot(rpm, Pe, rpm, Pm);		% plot two powers vs speed
xlabel('Speed, RPM');
ylabel('Watts, Pe and Pm');

