% Eigenvalue Analysis of a synchronous machine
% Copyright 1995, 1997 James L. Kirtley Jr.
% See 6.11s copyright statement for rules of use
% Must run parms.m first to get parameters and operating point
% Machine is assumed to be operating normally against a voltage
% source. No mechanical damping assumed
% First, operating point details
ip = ia * cos(psi);		% real current
ix = ia * sin(psi);		% reactive current
ra = .5*(xdpp+xqpp)/(ta*omz);	% armature time constant
ev = xq * ip - ra * ix;		% voltage components rel. to terminal
eh = vt + xq * ix + ra * ip;	% voltage, assumed to be real (h)
e1 = sqrt(ev^2+eh^2);		% calculation of steady operating point
delt = atan(ev/eh);		% torque angle
id = ia * sin(delt+psi);	% other elements of initial condition
iq = ia * cos(delt+psi);
eaf = e1 + (xd-xq)*id;		% voltage behind synchronous reactance
psid = vt * cos(delt) - ra*iq;	% armature flux components
psiq = - vt * sin(delt) + ra*id;
M=zeros(7);			% this is our transition matrix
				% detailed direct axis parameters
[xad xkdl xfl rkd rf] = mi(xd, xdp, xdpp, tdop, tdopp, xl, omz);
xkd = xad + xkdl;
xf = xad + xfl;
				% assemble direct axis inductance matrix
xmd = [xd xad xad; xad xkd xad; xad xad xf];
ymd = inv(xmd);			% invert to get admittances
				% now do the same for quad axis 
[xaq xkql rkq] = miq(xq, xqpp, tqopp, xl, omz);
xkq = xaq + xkql;
xmq = [xq xaq; xaq xkq];
ymq = inv(xmq);
ydd = ymd(1,1);			% elements of direct-axis admittance
ydk = ymd(1,2);
ykd = ymd(2,2);
ydf = ymd(1,3);
yff = ymd(3,3);
ykf = ymd(2,3);
yqq = ymq(1,1);			% elements of quad-axis admittance
yqk = ymq(1,2);
ykq = ymq(2,2);
% put together the transition matrix
M(1,1) = - omz*ra*ydd;
M(1,2) = - omz*ra*ydk;
M(1,3) = - omz*ra*ydf;
M(1,4) = omz;
M(1,6) = psiq;
M(1,7) = omz*vt*cos(delt);
M(2,1) = - omz*rkd*ydk;
M(2,2) = - omz*rkd*ykd;
M(2,3) = - omz*rkd*ykf;
M(3,1) = - omz*rf*ydf;
M(3,2) = - omz*rf*ykf;
M(3,3) = - omz*rf*yff;
M(4,1) = -omz;
M(4,4) = - omz*ra*yqq;
M(4,5) = - omz*ra*yqk;
M(4,6) = - psid;
M(4,7) = - omz*vt*sin(delt);
M(5,4) = - omz*rkq*yqk;
M(5,5) = - omz*rkq*ykq;
C = (.5*omz/H);
M(6,1) = C * (iq - ydd * psiq);
M(6,2) = - C * ydk * psiq;
M(6,3) = - C * ydf * psiq;
M(6,4) = C * (yqq * psid - id);
M(6,5) = C * yqk * psid;
M(7,6) = 1;
fprintf('Eigenvalues of a Synchronous Machine\n');
fprintf('xd = %g   xdp = %g   xdpp = %g\n',xd, xdp, xdpp);
fprintf('xq = %g   xqpp = %g\n',xq, xqpp);
fprintf('tdop = %g   tdopp = %g\n',tdop,tdopp);
fprintf('tqopp = %g   ta = %g\n',tqopp, ta);
fprintf('eaf = %g   delt = %g\n',eaf, delt);
fprintf('And here are the eigenvalues:\n');
S = eig(M)				% this step gets the eigenvalues

