% generalized fault simulator
% copyright 1995, 1997 James L. Kirtley Jr.
% see 611s copyright statement for rules of use
% must run par.m to get variables into workspace
global ydd ydk ykd ydf yff yqq yqk ykf ykq rf rkd rkq ra omz vf

% generate internal equivalent circuit parameters

[xad xkdl xfl rkd rf] = mi(xd, xdp, xdpp, tdop, tdopp, xl, omz);
[xaq xkql rkq] = miq(xq, xqpp, tqopp, xl, omz);
xkd = xad + xkdl;
xf = xad + xfl;

% this is the d- axis reactance matrix
xmd = [xd xad xad; xad xkd xad; xad xad xf];

% the inverse is used in simulation
ymd = inv(xmd);

% same drill for the quadrature axis
xkq = xaq + xkql;
xmq = [xq xaq; xaq xkq];
ymq = inv(xmq);

% and here are the admittances actually used to simulate
ydd = ymd(1,1);
ydk = ymd(1,2);
ykd = ymd(2,2);
ydf = ymd(1,3);
yff = ymd(3,3);
ykf = ymd(2,3);
yqq = ymq(1,1);
yqk = ymq(1,2);
ykq = ymq(2,2);

% armature resistance
ra = .5*(xdpp+xqpp)/(omz*ta);

% required field voltage
vf = rf/xad;
% flux vector is [psid psiq psikd psikq psif]
psi0 = [1 0 1 0 1+xfl/xad];		% here, from open circuit
a = 2*pi/3;
TF = dt*NP;
tspan = 0:dt:TF;
[t, psi] = ode23('sf',tspan,psi0);
id = ydd .* psi(:,1) + ydk .* psi(:,3) + ydf .* psi(:,5);
iq = yqq .* psi(:,2) + yqk .* psi(:,4);
tim = tspan';

ia = id .* cos (omz .* tim) - iq .* sin (omz .* tim);
ib = id .* cos (omz .* tim - a) - iq .* sin (omz .* tim - a);
ic = id .* cos (omz .* tim + a) - iq .* sin (omz .* tim + a);

% classical result
tdp = (xdp/xd)*tdop;
tdpp = (xdpp/xdp)*tdopp;
iac = (1/xdpp).*exp(-tim./ta) ...
      -(1/xd + (1/xdp - 1/xd).*exp(-tim./tdp) ...
        +(1/xdpp - 1/xdp).*exp(-tim./tdpp)) .* cos (omz .* tim);
figure(1)
clf
plot(tim,ia,tim,iac);
title('Comparison of Classical and Simulation');
xlabel('Time, s');
ylabel('Per-Unit Current');

