% Synchronous Machine Fault Simulator: Symmetrical Fault
% copyright 1995, 1997 James L. Kirtley Jr.
% See 611s Copyright Statement for Rules of Use
% presumes xd, xdp, xdpp, tdop, tdopp, xq, xqpp, tqopp and xl
% these can be loaded using par.m

global ydd ydk ykd ydf yff yqq yqk ykf ykq rf rkd rkq ra omz vf va H

% generate internal machine reactances from terminal variables
[xad xkdl xfl rkd rf] = mi(xd, xdp, xdpp, tdop, tdopp, xl, omz);
[xaq xkql rkq] = miq(xq, xqpp, tqopp, xl, omz);

xkd = xad + xkdl;
xf = xad + xfl;
xkq = xaq + xkql;

% assemble reactctance matrices
xmd = [xd xad xad; xad xkd xad; xad xad xf];
xmq = [xq xaq; xaq xkq];

% and invert them to get admittance parameters used in simulation

ymd = inv(xmd);
ymq = inv(xmq);

ydd = ymd(1,1);
ydk = ymd(1,2);
ykd = ymd(2,2);
ydf = ymd(1,3);
yff = ymd(3,3);
ykf = ymd(2,3);
yqq = ymq(1,1);
yqk = ymq(1,2);
ykq = ymq(2,2);
ra = .5*(xdpp+xqpp)/(omz*ta);
vf = rf/xad;
va = 1;

% flux vector is [psikd psikq psif omega delta]
fprintf('Simulation of Faulty Synchronization\n');
fprintf('Synchronous speed is 60 Hz (377 rad/sec)\n');
fprintf('Assumption is that angle is perfect, but\n');
fprintf('speed is not\n');
fprintf('Your input is actual machine speed (377 would be perfect)\n')
omzero = input('How Fast At Synchronization (Rad/sec) ==> ');
tf = input('Simulate for how long? (sec) ==> ');
NP = input('How many points to output? ==> ');
state0 = [1 0 1+xfl/xad omzero 0];

% the following loop is an artifice due to the small
% allowed matrices in Student Matlab

fprintf('Hang on: this may take a little while...\n');

dt = tf/NP;			% ignore what is in the input file
tspan = 0:dt:tf;  % this is the time vector
[t, state] = ode45('ds',tspan,state0);

tim = tspan';

delt = state(:,5);
fprintf('Done!\n');
figure(1)
clf
plot(tim,delt);
title('Faulty Synchronization');
xlabel('Time, s');
ylabel('Torque Angle');
