% operation of a PM motor
% copyright 1994 James L. Kirtley Jr.
% this is the per-unit part of determining rated
% operating point. It requires xd and xq, the
% per-unit-on-internal base reactances
% it also requires omratio, the ratio between
% maximum speed and base speed
% these numbers may have been computed by fcperf.m
% this calculation is done in per-unit: translation to
% real units takes place in other program modules
% Part 1: trajectory of optimal current placement
ia = .05:.05:1;
% note that the round-rotor case must be handled separately
if xd==xq,
  id = zeros(size(ia));
  iq = ia;
else
  c1 = .5 .* ia .^2;
  c2 = (1/(4*(xq-xd)))^2;
  id = -sqrt(c1 + 2*c2 - (.5/(xq-xd)).* sqrt(c2 + c1));
  iq = sqrt(c1 - 2*c2 + (.5/(xq-xd)).* sqrt(c2 + c1));
end
th = 0:pi/50:pi;
% here we just plot armature rating (current capability): a circle
idr = -sin(th);
iqr = cos(th);
% now to the (voltage) capability ellipse
% this is the range of currents that the machine can reach at
% its rated speed
% id0 and iq0 are the direct and quad axis currents at the rating point
% Psi is the per-unit terminal flux at that rated point
id0 = id(length(ia));
iq0 = iq(length(ia));
Psi = sqrt((1+xd*id0)^2+(xq*iq0)^2);
% Now we can compute a "base speed", which is related to terminal
% voltage and this terminal flux
omB = Va/(Lambda*Psi);
% fprintf('Base Speed Calculation: Va = %g  Psi = %g  ',Va,Psi);
% fprintf('Lambda = %g  omB = %g\n',Lambda,omB);
% idp is the direct axis characteristic of the ellipse
idp = Psi/xd;
% and we plot this ellipse all the way around
% the = 0:pi/25:2*pi;
% here are the two currents for the ellipse
% ide = idp .* cos(the)-1/xd;
% iqe = (xd/xq) * idp .* sin(the);
% OK: now we are going to generate a torque/speed curve
% Base RPM is:
rpmbase = (60/(2*p*pi))*omB;
fprintf('Base Speed (Rated Voltage) = %g RPM\n',rpmbase);
% the ratio of maximum to base speed is omratio
rpmm = omratio*rpmbase;
% there are two cases, depending on the value of xd
if xd<1,
% first, we must generate a minimum value for iq
% we go to zero torque speed if xd<1 and the called for speed ratio is high
% this case is easy, and iq is used as a parameter
  if omratio > Psi/(1-xd),        
    iqm = 0;
% now generate a vector of iq
    diq = (iq0-iqm)/50;
    iqs = iq0:-diq:iqm;
% current is always on the current capability frontier
    ids = -sqrt(1 - iqs .^2);
    te = (1 - (xq - xd) .* ids) .* iqs;
% psis is the flux produced by this pair of currents 
    psis = sqrt((1 + xd .* ids) .^2 + (xq .* iqs) .^2);
% and flux determines the speed
    omr = Psi ./ psis;
  else
% or we go to specified maximum speed
% here we use flux as the parameter
    psir = Psi/omratio;
    dpsi = (Psi-psir)/50;
    psis = Psi:-dpsi:psir;
    omr = Psi ./ psis;
% we need to handle the non-salient case separately
    if xd==xq,
      ids = (psis .^2 - 1 - xd^2)./(2 * xd);
    else    
      a = xd/(xq^2-xd^2);
      b = (xq^2-psis.^2+1)/(xq^2-xd^2);
      ids = a - sqrt(a^2+b);
    end
    iqs = sqrt(1-ids.^2);
    te = (1 - (xq - xd) .* ids) .* iqs;
% if we make it to max speed point, we compute a voltage
% limiting ellipse at that speed
% here is the voltage capability ellipse at max speed point
%    idpr = psir/xd;
%    ider = idpr .* cos(the)-1/xd;
%    iqer = (xd/xq) * idpr .* sin(the);
  end
% now we generate the case of xd>1
% Note: this is harder! But we can always make it to speed
else
% we use flux as the parameter here
  psir = Psi/omratio;
  dpsi = (Psi-psir)/50;
  psis = Psi:-dpsi:psir;
% but the complexity requires us to un-vectorize the calculation
  ids = zeros(size(psis));
  iqs = zeros(size(psis));
  for i=1:length(psis);
% here are the voltage limited currents that give maximum torque
    if xd==xq;
      idt = -1/xd;
      iqt = psis(i)/xq;
    else
      a = (3*xd*(xq-xd)-xd^2)/(2*xd^2*(xq-xd));
      b = ((xq-xd)*(psis(i) ^2 - 1) + xd)/(2*xd^2*(xq-xd));
      idt = -.5*a - sqrt((.5*a)^2 + b);
      iqt = (1/xq) * sqrt(psis(i)^2 - (1 + xd * idt) ^2);
    end
% but these may be outside the current capability curve
% if so, we must compute the intersection of voltage and current curves
    if sqrt(idt^2+iqt^2)>1,
      if xd==xq,
        ids(i)=(psis(i)^2-1-xd^2)/(2*xd);
      else
        a = xd/(xq^2-xd^2);
        b = (xq^2-psis(i)^2+1)/(xq^2-xd^2);
        ids(i) = a - sqrt(a^2+b);
      end
      iqs(i) = sqrt(1-ids(i)^2);
    else
      ids(i) = idt;
      iqs(i) = iqt;
    end
  end
  te = (1 - (xq - xd) .* ids) .* iqs;
  omr = Psi ./ psis;
% here is the voltage capability ellipse at max speed point
%  idpr = psir/xd;
%  ider = idpr .* cos(the)-1/xd;
%  iqer = (xd/xq) * idpr .* sin(the);
end


