% ************************************************************** %
%                                                                %
%                 Polyphase Motor Design Program                 %
%                            MOTOR                               %
%                     Single Squirrel Cage                       %
%       Parallel Rotor Body Conductivity (nonlinear model)       %
%                Copyright 1994, 1995, 1997, 2002                %
%                       J.L. Kirtley Jr.                         %
%                                                                %
% ************************************************************** %
% See 6.11s Copyright Statement for Rules of Use
% motout.m 
% Calculates and Prints Important Output Elements
% Requires motor.m to be run first

clc
fprintf('Induction Motor Analysis     Build Nov 16, 2002\n');
fprintf('Motor Rating =      %12.6g   Speed =             %12.0f RPM\n',pmech,rpm);
fprintf('Voltage =           %12.3f   Current =           %12.3f\n',volt,amps);
fprintf('Input Power (Watts)=%12.1f   Vars =              %12.1f\n',watts, vars);
fprintf('Efficiency =        %12.4f   Power Factor =      %12.4f\n',eff, pfact);
fprintf('Gap Shear =         %12.0f   Gap Heat Flux =     %12.0f\n',shear, hflux);
fprintf('Arm Cur Density =   %12.3g   Tip Speed =         %12.2f \n',Ja,tipsp);
fprintf('Tooth Flux Dens =   %12.2f   Core Flux Dens =    %12.2f\n',bt, bc);
fprintf('Gap Flux Dens =     %12.2f   Rot Tooth Flux =    %12.2f\n',bg,brt);
fprintf('Rotor Radius =      %12.3f   Active Length =     %12.3f\n',r,l);
% Calculation of Dimensions
% Outside Diameter
dout = 2*(r+g+ds+hs+db);
din  = 2*(r-dr-hr-db);
% Overall Electrical Length
lover = l+pi*r/p;
fprintf('Active Dimensions: (meters)\n');
fprintf('Weights (kg):                      Total Active =      %12.2f\n',mtot);
fprintf('Core Iron =         %12.2f   Rotor Iron =        %12.2f\n',mcore+mtooth,mcorer+mtoothr);
fprintf('Stator Conductor =  %12.2f   Rotor Conductor =   %12.2f\n\n',massa, massr);
fprintf('Details!\n');
fprintf('Rotor Radius     =  %12.5f   m        (inches) = %12.3f\n',r,r/.0254);
fprintf('Active Length    =  %12.5f   m        (inches) = %12.3f\n',l,l/.0254);
fprintf('Gap              =  %12.5f   m        (inches) = %12.3f\n',g,g/.0254);
fprintf('Overall Diameter    %12.4f   m        (inches) = %12.3f\n',dout,dout/.0254);
fprintf('Inner Diameter      %12.4f   m        (inches) = %12.3f\n',din, din/.0254);
fprintf('Overall El Length   %12.4f   m        (inches) = %12.3f\n',lover, lover/.0254);
fprintf('Poles Pairs      =  %12.0f\n',p);
fprintf('Number of Slots  =  %12.0f   Slots/Pole/Phase    %12.0f\n',ns, ma);
fprintf('Turns/Coil       =  %12.0f   Total Turns/Phase   %12.0f\n',nc, na);
fprintf('Wire Approx Dia  =  %12.4f   m        (inches) = %12.3f\n',sqrt(4*area/pi), sqrt(2*area/pi)/.0254);
fprintf('Stator Slot Depth   %12.4f   m        (inches) = %12.3f\n',hs, hs/.0254);
fprintf('Stator Slot Width   %12.4f   m        (inches) = %12.3f\n',ws, ws/.0254);
fprintf('Stator Depr Depth   %12.4f   m        (inches) = %12.3f\n',ds, ds/.0254);
fprintf('Stator Depr Width   %12.4f   m        (inches) = %12.3f\n',us, us/.0254);
fprintf('Stator Tooth Width  %12.4f   m        (inches) = %12.3f\n',wt, wt/.0254);
fprintf('Rotor  Slot Depth   %12.4f   m        (inches) = %12.3f\n',hr, hr/.0254);
fprintf('Rotor  Slot Width   %12.4f   m        (inches) = %12.3f\n',wr, wr/.0254);
fprintf('Rotor  Depr Depth   %12.4f   m        (inches) = %12.3f\n',dr, dr/.0254);
fprintf('Rotor  Depr Depth   %12.4f   m        (inches) = %12.3f\n',ur, ur/.0254);
fprintf('Back Iron Depth     %12.4f   m        (inches) = %12.3f\n',db, db/.0254);
fprintf('Stator Conductivity %12.3g   Cage Conductivity   %12.3g\n',siga,sigr);
fprintf('Rotor Body Cond     %12.3g\n',sirb);
if (sirb>0)
  fprintf('Calc Rotor Skin D   %12.4f   Used Rotor Skin D   %12.4f\n',deltap, delta);
end
fprintf('Loss Details:\n');
fprintf('Core Loss =         %12.3g   Armature Loss  =    %12.3g\n',Pc, Pa);
fprintf('Rotor Surf No-load  %12.3g   Load     =          %12.3g\n',Psurf,Pdt);
fprintf('Rotor Body No-Load  %12.3g   Air-Gap  =          %12.3f\n',Prsurf,pconv);
fprintf('Fan Load   =        %12.3g   Windage Loss =      %12.3g\n',pfan, pwind);
fprintf('Component Converted Cage  Body Loss Cage Body\n');
fprintf('Fund   %10g  %10g  ',pemf, pemfs);
fprintf('%10g  %10g\n',Pfc,Pfs);
fprintf('five   %10g  %10g  ',pem5c, pem5s);
fprintf('%10g  %10g\n',P5c,P5s);
fprintf('seven  %10g  %10g  ',pem7c, pem7s);
fprintf('%10g  %10g\n',P7c,P7s);
fprintf('zigneg %10g  %10g  ',pemmc, pemms);
fprintf('%10g  %10g\n',Pmc,Pms);
fprintf('zigpos %10g  %10g  ',pempc, pemps);
fprintf('%10g  %10g\n',Ppc,Pps);
%Paudit1=pconv-pslip-pmech-pfan-pwind-Psurf-Pdt-Prsurf;
Paudit1=pconv-pslip-pmech-pwind-Psurf-Pdt-Prsurf;
Paudit2=watts-pconv-Pc-Pa;
fprintf('Audits = %g   %g\n',Paudit1,Paudit2);



