% ------------------------------------------------------
% Torque-Speed Curve for an Induction Motor
% Assumes the classical model
% This is a single-circuit model
% Required parameters are R1, X1, X2, R2, Xm, Vt, Ns
% Assumed is a three-phase motor
% This thing does a motoring, full speed range curve
% Copyright 1994, 1997 James L. Kirtley Jr.
% See 6.11s Copyright Notice for Rules of Use
% -------------------------------------------------------
fprintf('Torque-Speed Curve Generation\n');

X1 = input('Stator Leakage X1 (ohms) ==> ');
X2 = input('Rotor Leakage X2 (ohms) ==> ');
Xm = input('Magnetizing Reactance Xm (ohms) ==> ');
R1 = input('Stator Resistance R1 (ohms) ==> ');
R2 = input('Rotor Resistance R2 (ohms) ==> ');
p = input('Number of Pole Pairs ==> ');
f = input('Line Frequency ==> ');
Vt = input('Line-Neutral Voltage (RMS) ==> ');

Ns = 60*f/p;			  % Synchronous Speed, RPM
oms = 2*pi*Ns/60;                 % Synchronous speed, rad/sec
s = logspace(-3, 0, 100);	  % get a nice vector of slips

N = Ns .* (1 - s);                % Speed, in RPM
Rr = R2 ./ s;                     % Rotor resistance 
Zr = j*X2 + Rr;                   % Total rotor impedance
Za = j*Xm .* Zr ./ (j*Xm + Zr);   % Air-gap impedance
Zt = R1 + j*X1 +Za;               % Terminal impedance
Ia = Vt ./ Zt;                    % Terminal Current
I2 = Ia .* j*Xm ./ (j*Xm + Zr);   % Rotor Current
Pag = 3 .* abs(I2) .^2 .* Rr;     % Air-Gap Power
Pm = Pag .* (1 - s);              % Converted Power
Trq = Pag ./ oms;                 % Developed Torque
figure(1)
subplot(2,1,1)
plot(N, Trq)
title('Induction Motor');
ylabel('N-m');
subplot(2,1,2)
plot(N, Pm);
ylabel('Watts');
xlabel('RPM');
