function [m,m2] = convpm(t,y);
%  [m,m2] = convpm(t,statev)
%
%  This script transforms the DQ stator currents computed using
%  pm.m and ode45 back into laboratory frame stator currents and voltages,
%  e.g., ias and vas for phase a. 
%
%  The variable w determines the reference frame in which the simulation
%  will be conducted.  With w = 377, the simulation variables will be in
%  a synchronously rotating reference frame.
%
%  On return, the output matrices m and m2 contain:
%	 m = [ids iqs];
%	 m2 = [T ias ibs ics vas vbs vcs];
%  This script also plots the simulated rotor torque versus speed on return.
%
%  This software is distributed in the hope that it will be useful, but
%  WITHOUT ANY WARRANTY.  It is for educational use only.  Please do not
%  distribute or sell this software, or remove the copyright notice.  
%
%  Copyright, 1995, 1997, 1998, 2000  Steven B. Leeb
global P rs Lls Lmq Lmd J lm vqs vds Tl
 iqs = y(:,1);
 ids = y(:,2);
 wr  = y(:,3);
 th  = y(:,4);
 Lq =  Lls+Lmq;
 Ld =  Lls+Lmd;
 lqs = Lq*iqs;
 lds = Ld*ids+lm;
 T     = (3/2)*(P/2)*(lds.*iqs - lqs.*ids);
 ias = cos(th).*ids - sin(th).*iqs;
 ibs = cos(th  - 2.*pi/3.).*ids - sin(th  - 2.*pi/3.).*iqs;
 ics = cos(th  + 2.*pi/3.).*ids -sin(th  + 2.*pi/3.).*iqs;
 vas = cos(th).*vds - sin(th).*vqs;
 vbs = cos(th  - 2.*pi/3.).*vds - sin(th  - 2.*pi/3.).*vqs;
 vcs = cos(th  + 2.*pi/3.).*vds - sin(th  + 2.*pi/3.).*vqs;
 m = [ids iqs];
 m2 = [T ias ibs ics vas vbs vcs];
 plot(2*3600*wr/(P*377),T);


