function [slopes] = pm(t,statev)
%  [slopes] = pm(t,statev)
%
%  This script computes the state variable derivatives for a third
%  order model of a balanced, three phase PM synchronous machine.
%  The state variables are the D and Q stator currents, and
%  the rotor speed (wr).
%  Use this script with ODE45 to simulate the performance of the 
%  PM machine.
%  
%  Run pmparam.m to load sample machine parameters before simulating.
%
%  This software is distributed in the hope that it will be useful, but
%  WITHOUT ANY WARRANTY.  It is for educational use only.  Please do not
%  distribute or sell this software, or remove the copyright notice.  
%
%  Copyright, 1995, 1997, 1998, 2000  Steven B. Leeb
% This simulation is conducted in a reference frame attached to the rotor.
global P rs Lls Lmq Lmd J lm vqs vds Tl
iqs = statev(1);
ids = statev(2);
wr    = statev(3);
th    = statev(4);
slopes = [0; 0; 0; 0;];
Lq =  Lls+Lmq;
Ld =  Lls+Lmd;
lqs = Lq*iqs;
lds = Ld*ids+lm;
s1 = (1/Lq)*(vqs - rs*iqs - wr*Ld*ids - wr*lm);
s2 = (1/Ld)*(vds - rs*ids + wr*Lq*iqs);
% P is the number of poles, *not* pole pairs
T         = (3/2)*(P/2)*(lds*iqs - lqs*ids);
s3 = (P/2)*(T - Tl)/J;
s4 = wr;
slopes = [s1 s2 s3 s4]';