function [slopes] = dcseries(t,statev)
%  [slopes] = dcseries(t,statev)
%
%  This script computes the state variable derivatives for a second
%  order model of a series connected, DC machine.
%  The state variables are armature current (ia) and the rotor speed (w).
%  Use this script with ODE45 to simulate the performance of the 
%  DC machine.
%  
%  Run dcparam.m to load sample machine parameters before simulating.
%
%  This software is distributed in the hope that it will be useful, but
%  WITHOUT ANY WARRANTY.  It is for educational use only.  Please do not
%  distribute or sell this software, or remove the copyright notice.  
%
%  Copyright, 1995, 1997, 1998, 2000  Steven B. Leeb
global Rf Ra Lf La G Bl Bm J va
ia  = statev(1);
w   = statev(2);
% Hook things in series:
iff = ia;
Las = La+Lf;
Ras = Ra+Rf;
% compute the derivatives:
s1 = (-G*w/Las)*iff - (Ras/Las)*ia + va/Las;
s2 = (-(Bm+Bl)/J)*w + (G/J)*iff*ia;

slopes = [s1 s2]';






