function [slopes] = dcshunt(t,statev)
%  [slopes] = dcshunt(t,statev)
%
%  This script computes the state variable derivatives for a third
%  order model of a shunt connected, DC machine.
%  The state variables are the field current (iff), the 
%  armature current (ia), and the rotor speed (w).
%  Use this script with ODE45 to simulate the performance of the 
%  DC machine.
%  
%  Run dcparam.m to load sample machine parameters before simulating.
%
%  This software is distributed in the hope that it will be useful, but
%  WITHOUT ANY WARRANTY.  It is for educational use only.  Please do not
%  distribute or sell this software, or remove the copyright notice.  
%
%  Copyright, 1995, 1998, 2000  Steven B. Leeb

global Rf Ra Lf La G Bl Bm J vf va

% load the machine parameters from the global environment

slopes = [0; 0; 0;];

iff = statev(1);
ia  = statev(2);
w   = statev(3);

% compute the derivative of field current:
slopes(1) = (-Rf/Lf)*iff + vf/Lf;
% compute the derivative of armature current:
slopes(2) = (-G*w/La)*iff - (Ra/La)*ia + va/La;
% compute the derivative of speed (acceleration):
slopes(3) = (-(Bm+Bl)/J)*w + (G/J)*iff*ia;
