% Zeroth Order Design of Step Type PM Motor
% Magnets Assumed Outside
% Copyright 1994, 1997 James L. Kirtley Jr.
% See 6.11s Copyright Notice for Rules of Use
% This is the main calculation procedure
% We assume in this design that p=r+1
% and number of teeth = 2*r
%
p = r+1;
Nt = 2*r;
% Rs is the outer magnetic boundary 
Rs = R + hm + g;
% n is the vector of space harmonic orders
n = 1:2:N;
% M is magnetization space harmonic amplitudes
M = ((4/pi) ./ n) .* sin ((thm/2) .* n) .* sin (n .* pi/2);
% some exponents are easier to calculate ahead of using them
n1 = n .* p -1;
n2 = n .* p +1;
n3 = 2*p .* n;
np = n .* p;
% K is the vector of shape functions, assembled from two parts
K1 = (R .^ n1) ./ (Rs .^ n3 - R .^ n3);
K2 = (np ./ n1) .* ((R+g).^(-n1) - Rs .^(-n1)) .* Rs .^ n3;
K3 = (np ./ n2) .* (Rs .^ n2 - (R+g) .^ n2);
H = M .* K1 .* (K2 + K3);
% B is the vector of actual magnetic flux densities:
B = Br .* H;
% Now to calculate stator current
% First to get slot bottom radius:
rsb = Nt*(wb+wt)/(2*pi);
% and then slot dimension
hs = R - hd - rsb;
% so As is total area of slots
As = pi * ((R-hd)^2 - rsb^2) - Nt * wt * hs;
% Now average surface current density is:
K0 = Js * As / (2 * pi * R);
% Next, computing the effective winding factors
% thp is the pole face angle
thp = (2*pi*R - Nt*wd)/(Nt*R);
% kn is the vector of winding factors:
kn = sin (n .* (p*thp/2));
% fn is the vector of time harmonic current amplitudes:
fn = (4 ./ (n .* pi)) .* sin (n .* tha/2);
% and now we can do torque: By component:
T = pi*R^2*L*K0 .* B .* kn .* fn;
Trq = sum(T);
% sie is developed surface stress, here in Pascals (SI Units)
sig = Trq/(2*pi*R^2*L);
% and here in English units (Sorry: PSI)
sie = sig/6895;
% add together for output
ss = [sig sie];
% now we can find flux in the stator teeth
% this is at the point at the end of the current pulse
Bt = (2*R/(p*wt)) .* B .* kn .* sin(n .* tha/2) ./ n;
Btm = sum(Bt);
% NI is ampere-turns per pole
NI = Js * As / Nt;
% 
% Now to find inductance per turn squared
muzero = pi * 4.0 * 10^(-7);
% Air-gap part:
Lg = muzero * R * thp * L / (g + hm);
% Slot leakage part:
% ws is slot top width
ws = 2 * pi * (R - wd) / Nt - wt;
% sd is a vector of slot dimensions
sd = [ws wb hs];
Ls = 2 * L * muzero * (.5*hs/ws + hd/wd);
Lt = [Ls Lg];
% Now to find tooth flux density due to current
Btg = Lg * NI / (wt * L);
Bts = Ls * NI / (wt * L);
Btt = [Btm Btg Bts Btg+Bts];
% and then xa is the internally normalized reactance
% lam is the flux linked, by component
lam = L * R * thp .* B .* kn;
% xas is slot part of reactance
xas = NI * Ls .* fn ./ lam;
% and xag is air-gap part  
xag = NI * Lg .* fn ./ lam;  
xa = xas + xag;
% omm is angular speed of the rotor
omm = 2*pi*RPM/60;
% and ome is the electrical frequency
ome = p*omm;
% here is developed power
Pwr = omm * Trq;
% and volts per turn, by harmonic
vpt = ome .* n .* lam;
svp = [omm ome Pwr Pwr/746];
% now we are gonna try to find losses
% these come predominantly from negative going harmonics
% here is the frequency of each of them
omn = 2 * ome .* n;
% and each has a wavenumber:
kwn = (2*pi/R)*(r-1) .* n; 
% and here is the winding factor for each:
knn = sin (n .* ((r-1)*thp/2));
% So that the developed surface current is:
Kn = K0 .* fn .* knn;
% next, we need to get the surface impedance
% complex wavenumber
alf = sqrt(j*muzero*sir.*omn + kwn.^2);
% rotor surface impedance is then 
Zr = j*muzero .* (omn ./ alf) ./ tanh ( alf .* hm);
% this translates across the gap by a distressingly complex expression:
A1 = muzero .* omn - j .* kwn .* Zr;
A2 = muzero .* omn + j .* kwn .* Zr;
B1 = exp(kwn .* g);
B2 = exp(-kwn .* g);
Zs = j * muzero .* (omn ./ kwn) .* (A1.*B1-A2.*B2)./(A1.*B1+A2.*B2);
Pdd = real(Zs) .* abs(Kn) .^2;
Pd = 2*pi*R*L*sum(Pdd);





