
% Setup Script for buried magnet motor-generator in NDA
% Copyright 1997  James L. Kirtley Jr.
% See 6.11s Copyright Notice for Rules of Use

NA = 8;				% attributes
ND = 10;			% continuous design space
NDE = 24;			% designs to keep
NITER = 500000;	    % shots to try

% Variables Inputs:
% Mean Values
R = .075;		    % Air-Gap Radius
g = .002;			% air gap
hm = .5*R;			% magnet width
wm = .005;			% magnet thickness
l = .1;				% active length
lamt = .5;			% tooth fraction
fsd = .2;			% slot depth to radius ratio
hd = .001;			% slot depression depth
wd = .001;			% slot depression width
fbi = .5;			% dimensionless back iron ratio
%fbi = .25;          % to demonstrate how limits work

% mean value vector
DM = [R g hm wm l lamt fsd hd wd fbi];	

% Standard Deviations
R = .025;				% Air-Gap Radius
g = .001;			% air gap
hm = .5*R;			% magnet width
wm = .0025;			% magnet thickness
l = .025;				% active length
lamt = .25;			% tooth fraction
fsd = .1;			% slot depth to radius ratio
hd = .0005;			% slot depression depth
wd = .0005;			% slot depression width
fbi = .15;			% dimensionless back iron ratio

DS = [R g hm wm l lamt fsd hd wd fbi];	


% Lower Limit
R = .0125;				% Air-Gap Radius
g = .001;			% air gap
hm = .25*R;			% magnet width
wm = .0025;			% magnet thickness
l = .025;				% active length
lamt = .3;			% tooth fraction
fsd = .05;			% slot depth to radius ratio
hd = .0005;			% slot depression depth
wd = .0005;			% slot depression width
fbi = .35;			% dimensionless back iron ratio

DL = [R g hm wm l lamt fsd hd wd fbi];

% Upper Limit
R = .15;				% Air-Gap Radius
g = .003;			% air gap
hm = .75*R;			% magnet width
wm = .015;			% magnet thickness
l = .25;				% active length
lamt = .6;			% tooth fraction
fsd = .3;			% slot depth to radius ratio
hd = .002;			% slot depression depth
wd = .002;			% slot depression width
fbi = 1.0;			% dimensionless back iron ratio

DU = [R g hm wm l lamt fsd hd wd fbi];

% fast and dirty
%DS = .2 .* DM;
%DL = .5 .* DM;
%DU = 1.5 .* DM;

% Limits of integer variables
pmax = 8;
mmax = 3;
Nspmax = 2;

DIN = [pmax mmax Nspmax];


GRg = 3;			% generating gear ratio
GRm = 15;			% motoring gear ratio

% fixed inputs

rpm = 600 * GRg;		% generating rotational speed
Preq = 4286;			% required generation 
psi = 0;			% power factor angle
Treq = 300/GRm;			% required motoring torque
lama = .35;			% armature packing factor
Br = .9;			% MG-2 type stuff
siga = 4.5e7;			% warm copper
P0 = 1.3;			% iron loss model: loss at
B0 = 1;				% base flux density (RMS)
F0 = 60;			% base frequency (Hz)
epb = 1.89;			% flux density exponent
epf = 1.62;			% frequency exponent
Jmlim = 5e7;			% conductor motoring current density limit
Jglim = 6e6;			% conductor generating current density limit
Pmag = 50;			% magnet price: $/kg
Pcu = 2.205*2.27;		% copper price
Pfe = 2.205*.45;		% iron price
Ploss = 0.10;          % loss price: dollars per watt
Bsat = 2.0;			% maximum flux density
rpm2 = 1500*GRg;		% speed at efficiency point
etamin = .804;			% efficiency bogey
Preq2 = 3214;			% power at eff bogey
Ph = 5;				% price of banding
Dmax = .3;			% diameter
Lmax = .330;			% length
Rmax = 5;			% D/L ratio

B = [rpm Preq psi Treq lama Br siga P0 B0 F0 epb epf Jmlim ...
     Jglim Pmag Pcu Pfe Bsat rpm2 etamin Preq2 Ph Dmax Lmax Rmax Ploss];

% Here are the matrices that NDA will fill out

MA = zeros(NDE, NA);		% design attributes across rows
MD = zeros(NDE, ND);		% design variables (continuous)
NI = length(DIN);		% number of integer variables
MDI = zeros(NDE, NI);		% design variables (integers)
DI = zeros(size(DIN));		% space for integer variables

MAOpt = zeros(NDE, NA);		% scratchpad for optimized machine
MDOpt = zeros(NDE, ND);		% ditto

[A, C] = attribut(DM, DIN, B, 1)
