% 
% ************************************************************** %
%                                                                %
%                Novice Design Assistant Lite                    %
%                              nda                               %
%                       J.L. Kirtley Jr.                         %
%                                                                %
% ************************************************************** %
%
% Copyright 1997, James L. Kirtley Jr.
% See 6.11s Copyright Notice for Rules of Use

% Requires an attribute generating function called this way:
% [A, g] = attribut(D, DI, B, Out)
% A is a vector of attributes of size NA
%   Attributes are all positive and goodness is in increase
% g is a scalar that is 0 if a design is not viable and 1 if it is
% D is a vector of design variables that ndi will manipulate
%   it is of size ND
% DI is a vector of integer variables to be varied randomly
%   it is of size NI
% B is a vector of design variables that will remain fixed
% Out = 1 will cause the thing to print
% DL, DU, DS and DM are starting points for the vector D
% DL and DU are lower and upper limit points
% DM is the median value to be used in generating D
% DS is a vector of standard deviation to be used in generating D
% DIN is the vector of ranges of the elements of DI
% NDE is the number of design points to be accumulated
% NITER is the total number of shots to be tried
% Output will be accumulated in two matrices
% MA [NA, NDE] holds the attributes of all designs
% MD [ND, NDE] holds the design variables
% These matrices are declared in the setup program, so
% that NDA can be run over again
multi_dom = 0;                      % so we don't get an error message

for i = 1:NITER,

  D = DM + DS .* randn(1, ND);		% generate a random input
  if sum([DL>D DU<D]) == 0,		% if design is in range, continue
    %fprintf('in range\n')
    for ii = 1:NI,			% generate the integer random
     pt = randperm(DIN(ii));            % variables
     DI(ii) = pt(1);
    end

    [A, g] = attribut(D, DI, B, 0);	% generate design
    if g ~= 0,				% if viable, do dominance check 
      inserted = 0;                     % used later
      multi_dom = 0;
      for nd=1:NDE,			% dominance check
          %sum(A>MA(nd, :))
       if sum(A>MA(nd,:))== 0,		% design is dominated
         break, 
       end;				
       %if ((sum(MA(nd,:)>A) == 0) && (sum(MA(nd, :)) >0 )),   % design dominates
       if sum(MA(nd, :) > A ) == 0,
         if inserted == 0;	  	% this is the first dominated design
           inserted = 1;
           MA(nd, :) = A;		% it goes here
           MD(nd, :) = D;		% save design too!
           MDI(nd, :) = DI;
           fprintf('Replacing Design %5.0f At Step %5.0f\n', nd, i);
         else
           multi_dom = 1;               % flag need for cleanup later
           MA(nd, :) = zeros(size(A));  % clobber dominated design
           MD(nd, :) = zeros(size(D));
           MDI(nd, :) = zeros(size(DI));
         end                            % end of if inserted
       end				% end of dominating design
      end				% end of check loop
    end                                 % end of dominance check
    if multi_dom == 1;			% need to clean up matrices
      for nd = 1:NDE,			% scan attribute matrix
        if sum(MA(nd, :)) == 0,		% hole found
          for ndd = nd:NDE,		% scan rest of file
            if sum(MA(ndd, :)) > 0;	% first non-zero design
              fprintf('Design %5.0f Is Dominated At Step %5.0f \n', nd, i);
              MA(nd, :) = MA(ndd, :);	% copy upward
              MD(nd, :) = MD(ndd, :);
              MDI(nd, :) = MDI(ndd, :);
              MA(ndd, :) = zeros(size(A));	% and erase
              MD(ndd, :) = zeros(size(D));
              MDI(ndd, :) = zeros(size(DI));
              multi_dom = 0;
              break;                    % only move one design
            end                         % end if nonzero
          end                           % end of scan rest of design
        end                             % end if hold found
      end				% end scan attribute matrix
    end 				% end cleanup 
    %else fprintf('out of range\n')
  end           % end of input range check  
end					% that's all folks!
