% 
% ************************************************************** %
%                                                                %
%                       Random Optimizer                         %
%                             ropt                               %
%                       J.L. Kirtley Jr.                         %
%                                                                %
% ************************************************************** %
%
% Copyright 1997, James L. Kirtley Jr.
% See 6.11s Copyright Notice for Rules of Use

% This program is intended to operate in conjunction with nda.m
% Requires an attribute generating function called this way:
% [A, g] = attribut(D, DI, B, Out)
% A is a vector of attributes of size NA
%   Attributes are all positive and goodness is in increase
% ropt tries to maximize A(1), which should be the objective function
% g is a scalar that is 0 if a design is not viable and 1 if it is
% D is a vector of design variables that ndi will manipulate
%   it is of size ND
% DI is a vector of integer variables to be varied randomly
%   it is of size NI
% B is a vector of design variables that will remain fixed
% Out = 1 will cause the thing to print
% DL, DU, DS and DM are starting points for the vector D
% DL and DU are lower and upper limit points
% DM is the median value to be used in generating D
% DS is a vector of standard deviation to be used in generating D
% DIN is the vector of ranges of the elements of DI
% NDE is the number of design points to be accumulated
% NITER is the total number of shots to be tried
% Output from nda is accumulated in two matrices
% MA [NA, NDE] holds the attributes of all designs
% MD [ND, NDE] holds the design variables
% MDI [NI, NDE] holds the integer design variables

NCYCLES = input('How many reduction cycles? ==>');
NITER = input('How many shots per cycle? ==>');
RF = input('What reduction in STDEV/cycle? ==>');
N = input('Which design do we start from? ==>');

DM = MD(N,:);				% this is the starting point design
DI = MDI(N,:);				% use the integer variables as is

[A, g] = attribut(DM, DI, B, 1);		% generate design
V=A(1);					% starting point

for i = 1:NITER,

  D = DM + DS .* randn(1, ND);		% generate a random input
  if sum([DL>D DU<D]) == 0,		% if design is in range, continue

    [A, g] = attribut(D, DI, B, 0);	% generate design

    if g ~= 0,				% if viable, check objective value
      if A(1) > V,			% indicates improvements
        DM = D;				% save design for later
      end				% end dominance check
    end					% end viability check
  end					% end range check
end					% end first iteration

% now we refine only the continuous variables: DI is fixed

for ic = 1:NCYCLES,
  DS = DS .* RF;			% reduce STD of search

  for i = 1:NITER,

    D = DM + DS .* randn(1, ND);	% generate a random input
    if sum([DL>D DU<D]) == 0,		% if design is in range, continue

      [A, g] = attribut(D, DI, B, 0);	% generate design

      if g ~= 0,			% if viable, check objective value
        if A(1) > V,			% indicates improvements
          DM = D;			% save design for later
          V = A(1);			% this is the new reference design
        end				% end dominance check
      end				% end viability check
    end					% end range check
  end					% end iteration
  [A, g] = attribut(DM, DI, B, 1);	% display results of this cycle
end
